==> aws-android-sdk-ddb-2.1.8-sources.jar: main/java/com/amazonaws/services/cognitoidentity/model/transform/CreateIdentityPoolRequestMarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cognitoidentity.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.cognitoidentity.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * Create Identity Pool Request Marshaller
 */
public class CreateIdentityPoolRequestMarshaller implements Marshaller<Request<CreateIdentityPoolRequest>, CreateIdentityPoolRequest> {

    public Request<CreateIdentityPoolRequest> marshall(CreateIdentityPoolRequest createIdentityPoolRequest) {
    if (createIdentityPoolRequest == null) {
        throw new AmazonClientException("Invalid argument passed to marshall(...)");
    }

        Request<CreateIdentityPoolRequest> request = new DefaultRequest<CreateIdentityPoolRequest>(createIdentityPoolRequest, "AmazonCognitoIdentity");
        String target = "AWSCognitoIdentityService.CreateIdentityPool";
        request.addHeader("X-Amz-Target", target);

        request.setHttpMethod(HttpMethodName.POST);
        request.setResourcePath("");
        
        try {
          StringWriter stringWriter = new StringWriter();
          JSONWriter jsonWriter = new JSONWriter(stringWriter);

          jsonWriter.object();
          
            if (createIdentityPoolRequest.getIdentityPoolName() != null) {
                jsonWriter.key("IdentityPoolName").value(createIdentityPoolRequest.getIdentityPoolName());
            }
            if (createIdentityPoolRequest.isAllowUnauthenticatedIdentities() != null) {
                jsonWriter.key("AllowUnauthenticatedIdentities").value(createIdentityPoolRequest.isAllowUnauthenticatedIdentities());
            }
            if (createIdentityPoolRequest.getSupportedLoginProviders() != null) {
                jsonWriter.key("SupportedLoginProviders");
                jsonWriter.object();
                for (Map.Entry<String, String> supportedLoginProvidersListValue : createIdentityPoolRequest.getSupportedLoginProviders().entrySet()) {
                    if (supportedLoginProvidersListValue.getValue() != null) {
                        jsonWriter.key(supportedLoginProvidersListValue.getKey());

                        jsonWriter.value(supportedLoginProvidersListValue.getValue());
                    }
                }
                jsonWriter.endObject();
            }
            if (createIdentityPoolRequest.getDeveloperProviderName() != null) {
                jsonWriter.key("DeveloperProviderName").value(createIdentityPoolRequest.getDeveloperProviderName());
            }

            com.amazonaws.internal.ListWithAutoConstructFlag<String> openIdConnectProviderARNsList = (com.amazonaws.internal.ListWithAutoConstructFlag<String>)(createIdentityPoolRequest.getOpenIdConnectProviderARNs());
            if (openIdConnectProviderARNsList != null && !(openIdConnectProviderARNsList.isAutoConstruct() && openIdConnectProviderARNsList.isEmpty())) {

                jsonWriter.key("OpenIdConnectProviderARNs");
                jsonWriter.array();

                for (String openIdConnectProviderARNsListValue : openIdConnectProviderARNsList) {
                    if (openIdConnectProviderARNsListValue != null) {
                        jsonWriter.value(openIdConnectProviderARNsListValue);
                    }
                }
                jsonWriter.endArray();
            }

          jsonWriter.endObject();

          String snippet = stringWriter.toString();
          byte[] content = snippet.getBytes(UTF8);
          request.setContent(new StringInputStream(snippet));
          request.addHeader("Content-Length", Integer.toString(content.length));
          request.addHeader("Content-Type", "application/x-amz-json-1.0");
        } catch(Throwable t) {
          throw new AmazonClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }
}

==> aws-android-sdk-ddb-2.1.10-sources.jar: main/java/com/amazonaws/services/cognitoidentity/model/transform/CreateIdentityPoolRequestMarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.cognitoidentity.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.http.HttpMethodName;
import com.amazonaws.services.cognitoidentity.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.AwsJsonWriter;
import com.amazonaws.util.json.JsonUtils;

/**
 * Create Identity Pool Request Marshaller
 */
public class CreateIdentityPoolRequestMarshaller implements Marshaller<Request<CreateIdentityPoolRequest>, CreateIdentityPoolRequest> {

    public Request<CreateIdentityPoolRequest> marshall(CreateIdentityPoolRequest createIdentityPoolRequest) {
    if (createIdentityPoolRequest == null) {
        throw new AmazonClientException("Invalid argument passed to marshall(...)");
    }

        Request<CreateIdentityPoolRequest> request = new DefaultRequest<CreateIdentityPoolRequest>(createIdentityPoolRequest, "AmazonCognitoIdentity");
        String target = "AWSCognitoIdentityService.CreateIdentityPool";
        request.addHeader("X-Amz-Target", target);

        request.setHttpMethod(HttpMethodName.POST);
        request.setResourcePath("");
        
        try {
            StringWriter stringWriter = new StringWriter();
            AwsJsonWriter jsonWriter = JsonUtils.getJsonWriter(stringWriter);

            jsonWriter.beginObject();
            
            if (createIdentityPoolRequest.getIdentityPoolName() != null) {
                jsonWriter.name("IdentityPoolName").value(createIdentityPoolRequest.getIdentityPoolName());
            }
            if (createIdentityPoolRequest.isAllowUnauthenticatedIdentities() != null) {
                jsonWriter.name("AllowUnauthenticatedIdentities").value(createIdentityPoolRequest.isAllowUnauthenticatedIdentities());
            }
            if (createIdentityPoolRequest.getSupportedLoginProviders() != null) {
                jsonWriter.name("SupportedLoginProviders");
                jsonWriter.beginObject();
                for (Map.Entry<String, String> supportedLoginProvidersListValue : createIdentityPoolRequest.getSupportedLoginProviders().entrySet()) {
                    if (supportedLoginProvidersListValue.getValue() != null) {
                        jsonWriter.name(supportedLoginProvidersListValue.getKey());

                        jsonWriter.value(supportedLoginProvidersListValue.getValue());
                    }
                }
                jsonWriter.endObject();
            }
            if (createIdentityPoolRequest.getDeveloperProviderName() != null) {
                jsonWriter.name("DeveloperProviderName").value(createIdentityPoolRequest.getDeveloperProviderName());
            }

            com.amazonaws.internal.ListWithAutoConstructFlag<String> openIdConnectProviderARNsList = (com.amazonaws.internal.ListWithAutoConstructFlag<String>)(createIdentityPoolRequest.getOpenIdConnectProviderARNs());
            if (openIdConnectProviderARNsList != null && !(openIdConnectProviderARNsList.isAutoConstruct() && openIdConnectProviderARNsList.isEmpty())) {

                jsonWriter.name("OpenIdConnectProviderARNs");
                jsonWriter.beginArray();

                for (String openIdConnectProviderARNsListValue : openIdConnectProviderARNsList) {
                    if (openIdConnectProviderARNsListValue != null) {
                        jsonWriter.value(openIdConnectProviderARNsListValue);
                    }
                }
                jsonWriter.endArray();
            }

            jsonWriter.endObject();

            jsonWriter.close();
            String snippet = stringWriter.toString();
            byte[] content = snippet.getBytes(UTF8);
            request.setContent(new StringInputStream(snippet));
            request.addHeader("Content-Length", Integer.toString(content.length));
            request.addHeader("Content-Type", "application/x-amz-json-1.0");
        } catch(Throwable t) {
            throw new AmazonClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }

        return request;
    }
}
